@@ -8,52 +8,39 @@ import (
 	"encoding/json"
 	"flag"
 	"io"
-	"io/ioutil"
 	"net"
 	"os"
 	"path/filepath"
+	"testing"
 	"time"
 
-	"github.com/spf13/afero"
+	"github.com/stretchr/testify/require"
 
 	"github.com/aquasecurity/trivy-db/pkg/db"
 )
 
 var update = flag.Bool("update", false, "update golden files")
 
-func gunzipDB() (string, error) {
+func gunzipDB(t *testing.T) string {
 	gz, err := os.Open("testdata/trivy.db.gz")
-	if err != nil {
-		return "", err
-	}
+	require.NoError(t, err)
+
 	zr, err := gzip.NewReader(gz)
-	if err != nil {
-		return "", err
-	}
-
-	tmpDir, err := ioutil.TempDir("", "integration")
-	if err != nil {
-		return "", err
-	}
+	require.NoError(t, err)
 
+	tmpDir := t.TempDir()
 	dbPath := db.Path(tmpDir)
 	dbDir := filepath.Dir(dbPath)
 	err = os.MkdirAll(dbDir, 0700)
-	if err != nil {
-		return "", err
-	}
+	require.NoError(t, err)
 
 	file, err := os.Create(dbPath)
-	if err != nil {
-		return "", err
-	}
+	require.NoError(t, err)
 	defer file.Close()
 
-	if _, err = io.Copy(file, zr); err != nil {
-		return "", err
-	}
+	_, err = io.Copy(file, zr)
+	require.NoError(t, err)
 
-	fs := afero.NewOsFs()
 	metadataFile := filepath.Join(dbDir, "metadata.json")
 	b, err := json.Marshal(db.Metadata{
 		Version:    1,
@@ -61,15 +48,12 @@ func gunzipDB() (string, error) {
 		NextUpdate: time.Time{},
 		UpdatedAt:  time.Time{},
 	})
-	if err != nil {
-		return "", err
-	}
-	err = afero.WriteFile(fs, metadataFile, b, 0600)
-	if err != nil {
-		return "", err
-	}
+	require.NoError(t, err)
 
-	return tmpDir, nil
+	err = os.WriteFile(metadataFile, b, 0600)
+	require.NoError(t, err)
+
+	return tmpDir
 }
 
 func getFreePort() (int, error) {
